@@ -1,4 +1,4 @@
-# Copyright 2022 c0fec0de
+# Copyright 2022-2023 c0fec0de
 #
 # This file is part of Git Workspace.
 #
@@ -53,9 +53,16 @@ from .remote import remote
 _LOGGING_FORMAT = "%(name)s %(levelname)s %(message)s"
 
 
+def _version_option():  # pragma: no cover
+    # Add support for click 7.x.x and click 8.x.x
+    if click.version_option.__kwdefaults__ and "package_name" in click.version_option.__kwdefaults__:
+        return click.version_option(package_name="git-ws")
+    return click.version_option()
+
+
 @click.group(context_settings={"help_option_names": ["-h", "--help"]})
 @click.option("-v", "--verbose", count=True)
-@click.version_option(package_name="git-ws")
+@_version_option()
 @click.pass_context
 def main(ctx=None, verbose=0):
     """
@@ -490,7 +497,7 @@ def submodule(context, command, projects=None, manifest_path=None, group_filters
 
 @main.command()
 @manifest_option(initial=True)
-@click.argument("name", type=click.Choice(tuple(Defaults.__fields__)))
+@click.argument("name", type=click.Choice(tuple(Defaults().dict(by_alias=True))))
 @click.argument("value")
 @pass_context
 def default(context, manifest_path, name, value):
@@ -505,7 +512,7 @@ def default(context, manifest_path, name, value):
         manifest_spec.save(manifest_path)
 
 
-@main.command()
+@main.command(name="group-filters")
 @manifest_option(initial=True)
 @click.argument("value")
 @pass_context
