@@ -1,4 +1,4 @@
-# Copyright 2022 c0fec0de
+# Copyright 2022-2023 c0fec0de
 #
 # This file is part of Git Workspace.
 #
@@ -14,7 +14,12 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with Git Workspace. If not, see <https://www.gnu.org/licenses/>.
 
-""":any:`Manifest` and :any:`Project` Iterators."""
+"""
+Helpers to iterate over all :any:`Manifest` or :any:`Project` instances.
+
+Please note, these iterators require a :any:`Workspace` with existing manifest files within.
+The creation/cloning of missing project dependencies during the iteration is supported.
+"""
 import logging
 from fnmatch import fnmatchcase
 from pathlib import Path
@@ -35,7 +40,7 @@ class ManifestIter:
     """
     Iterate over all :any:`Manifest` s.
 
-    The iterator takes a ``workspace`` and the path to a manifest file (`manifest_path`) of the main project.
+    The iterator takes a :any:`Workspace` and the path to a manifest file (`manifest_path`) of the main project.
     The manifest is read (:any:`ManifestSpec`) and translated to a :any:`Manifest`, which is yielded.
     The manifest files of the dependencies are also read, translated to a :any:`Manifest` and yielded likewise,
     until all manifest files and their dependencies are read.
@@ -44,7 +49,7 @@ class ManifestIter:
 
     Args:
         workspace: The actual workspace
-        manifest_path: Path to the manifest file **in the main project**.
+        manifest_path: Path to the manifest file.
         group_filters: Group Filters.
 
     Yields:
@@ -112,7 +117,7 @@ class ProjectIter:
     """
     Iterate over all :any:`Project` s.
 
-    The iterator takes a ``workspace`` and the path to a manifest file (`manifest_path`) of the main project.
+    The iterator takes a :any:`Workspace` and the path to a manifest file (`manifest_path`) of the main project.
     The manifest is read (:any:`ManifestSpec`) and all dependencies are translated to :any:`Project` s, which are
     yielded.
     The manifest files of the dependencies are also read, translated to a :any:`Project` s and yielded likewise,
@@ -238,7 +243,7 @@ def create_filter(group_selects: GroupSelects, default: bool = False) -> FilterF
         group_selects: Iterable with :any:`GroupSelect`.
         default: Default selection of all ``groups``.
 
-    >>> group_filters = ('+test', '+doc', '+feature@dep', '-doc')
+    >>> group_filters = ('-@special', '+test', '+doc', '+feature@dep', '-doc')
     >>> group_selects = GroupSelects.from_group_filters(group_filters)
     >>> groupfilter = create_filter(group_selects)
     >>> groupfilter('sub', tuple())  # selected as there is no group
@@ -255,6 +260,14 @@ def create_filter(group_selects: GroupSelects, default: bool = False) -> FilterF
     False
     >>> groupfilter('dep', ('feature',))  # 'feature' is only selected for 'dep'
     True
+    >>> groupfilter('special', tuple())  # deselected, even without group
+    False
+    >>> groupfilter('special', ('foo', 'bar'))  # deselected
+    False
+    >>> groupfilter('special', ('test', 'bar'))  # deselected, but overwritten by '+test'
+    True
+
+    The same, but with ``default=True``:
 
     >>> groupfilter = create_filter(group_selects, default=True)
     >>> groupfilter('sub', tuple())  # selected as there is no group
@@ -271,6 +284,12 @@ def create_filter(group_selects: GroupSelects, default: bool = False) -> FilterF
     True
     >>> groupfilter('dep', ('feature',))  # 'feature' is only selected for 'dep'
     True
+    >>> groupfilter('special', tuple())  # deselected, even without group
+    False
+    >>> groupfilter('special', ('foo', 'bar'))  # deselected
+    False
+    >>> groupfilter('special', ('test', 'bar'))  # deselected, but overwritten by '+test'
+    True
     """
 
     if group_selects:
@@ -278,16 +297,21 @@ def create_filter(group_selects: GroupSelects, default: bool = False) -> FilterF
         def filter_(path: str, groups: Groups):
             if groups:
                 selects = {group: default for group in groups}
-                for group_select in group_selects:
-                    if group_select.group not in selects:
-                        # not relevant group name
-                        continue
-                    if group_select.path and not fnmatchcase(path, group_select.path):
-                        # not relevant path
-                        continue
-                    selects[group_select.group] = group_select.select
-                return any(selects.values())
-            return True
+            else:
+                selects = {None: True}
+            for group_select in group_selects:
+                group = group_select.group
+                if group and group not in selects:
+                    # not relevant group name
+                    continue
+                if group_select.path and not fnmatchcase(path, group_select.path):
+                    # not relevant path
+                    continue
+                if group:
+                    selects[group] = group_select.select
+                else:
+                    selects = {group: group_select.select for group in selects}
+            return any(selects.values())
 
     else:
 
